library(org.Hs.eg.db)
# library(pathview)
# library(AnnotationHub)
library(ensembldb)
library(tidyverse)
library(SPIA)
library(annotables)
library(clusterProfiler)
#Set working dir
setwd("~/iCloud_IDM/Nono/")

## Explore the human annotation table loaded by the annotables library
grch37

##Load DE results of interest
C1_4 <- read.csv("edgeR_Unfiltered_input_cluster1_vs_4_FDR_0_1.csv", sep = ",")
str(C1_4)
## Return the IDs for the gene symbols in the DE results
idx_b <- grch37$symbol %in% C1_4$genes
ids_b <- grch37[idx_b, ]
str(ids_b)
ids_b$entrez <- as.character(ids_b$entrez)
dim(ids_b)#69 9

## The gene names can map to more than one Ensembl ID (some genes change ID over time), 
## so we need to remove duplicate IDs prior to assessing enriched GO terms
length(which(duplicated(ids_b$symbol) == TRUE))#10
ids_b$symbol[which(duplicated(ids_b$symbol))]
non_duplicates_b <- which(duplicated(ids_b$symbol) == FALSE)
length(non_duplicates_b)#59
ids_b <- ids_b[non_duplicates_b, ] 
#

## Merge the IDs with the results 
#
res_ids_b <- inner_join(C1_4, ids_b, by=c("genes"="symbol"))         
dim(res_ids_b)#59 16
#
#---
## Remove any NA values
res_entrez_b <- dplyr::filter(res_ids_b, entrez != "NA")
dim(res_entrez_b)#55
#
## Remove any Entrez duplicates
res_entrez_b<- res_entrez_b[which(duplicated(res_entrez_b$entrez) == F), ]

## Significant genes is a vector of fold changes where the names are ENTREZ gene IDs. The background set is a vector of all the genes represented on the platform.
full_gene_list <- readRDS("severin_ensembl_gchr37_annotation.rds")
head(full_gene_list)
str(full_gene_list)
idx_full <- grch37$symbol %in% full_gene_list$external_gene_name
ids_full <- grch37[idx_full, ]
str(ids_full)
ids_full$entrez <- as.character(ids_full$entrez)
dim(ids_full)#66987
## Remove any NA values
full_entrez <- dplyr::filter(ids_full, entrez != "NA")
dim(full_entrez)#31112
## Remove any Entrez duplicates
full_entrez <- full_entrez[which(duplicated(full_entrez$entrez) == F), ]

background_entrez <- full_entrez$entrez

#SPIA 
sig_res_entrez <- res_entrez_b[which(res_entrez_b$PValue < 0.05), ]
sig_entrez_FC<- as.numeric(sig_res_entrez$logFC)
names(sig_entrez_FC) <- sig_res_entrez$entrez
head(sig_entrez_FC)
setdiff(names(sig_entrez_FC),background_entrez)#6196
spia_result <- spia(de=sig_entrez_FC, all=background_entrez, organism="hsa")
write.csv2(spia_result[spia_result$pG < 0.05,],"SPIA_cluster_1_vs_4_p_0_05.csv")

#ClusterProfiler GO enrichment analysis
## Run GO enrichment analysis 
#
res_entrez_b <- res_ids_b
sig_res_entrez <- res_entrez_b[which(res_entrez_b$PValue < 0.05), ]
dim(sig_res_entrez)#59
eGO <- enrichGO(gene = sig_res_entrez$ensgene, 
                         keyType = "ENSEMBL",
                         OrgDb = org.Hs.eg.db, 
                         ont = "ALL", 
                         pAdjustMethod = "BH", 
                         qvalueCutoff = 0.1, 
                         readable = TRUE)
#
## Output results from GO analysis to a table
eGO <- data.frame(eGO)

write.csv(eGO, "clusterProfiler_cluster_1_vs_4.csv")

#/////////////////////////

