#SCRIPT PURPOSE: redo Nono RNAseq (1st run analysis) using R package EBseq (primary analysis was done using edgeR). This will serve to validate and compare results using
#the two different methods
#Briefly, EBseq is an empirical Bayesian approach that models a number of
# features observed in RNA-seq data. Importantly, for isoform level inference, EBSeq directly accommodates
# isoform expression estimation uncertainty by modeling the differential variability observed in distinct groups
# of isoforms
#---------------------------------------------
library(EBSeq)
library(edgeR)
library(NMF)
setwd("/Users/katielennard/Documents/Katie/IDM_projects/Nono/RNAseq/")
setwd("/Users/katielennard/Documents/Academic/IDM_projects/Nono/Severin/")
#---------------DATA IMPORT------------------------------
#Raw count data import:
ribo_minus <- readRDS("ribo_minus_counts.rds")
dim(ribo_minus)#52114 36
#-----------------------------
#Import gene annotation (creaetd in Nono_RNAseq.R), object named 'gene'
RM_anno <- readRDS("RM_anno.rds")
dim(RM_anno)#52114 4
#-----------------------------
#import sample metadata
sev_meta <- readRDS("sev_meta.rds")

#subset clusters 1 and 4
one_four <- sev_meta[sev_meta$Group == "Cluster_1" | sev_meta$Group == "Cluster_4",]
one_four$Group <- as.factor(as.character(unlist(one_four$Group)))
Rcounts_one_four <- ribo_minus[,rownames(one_four)]
dim(Rcounts_one_four)#52114 15
#subset clusters 1 and 3
one_three <- sev_meta[sev_meta$Group == "Cluster_1" | sev_meta$Group == "Cluster_3",]
one_three$Group <- as.factor(as.character(unlist(one_three$Group)))
Rcounts_one_three <- ribo_minus[,rownames(one_three)]
dim(Rcounts_one_three)#52114 20
#subset clusters 3 and 4
three_four <- sev_meta[sev_meta$Group == "Cluster_3" | sev_meta$Group == "Cluster_4",]
three_four$Group <- as.factor(as.character(unlist(three_four$Group)))
Rcounts_three_four <- ribo_minus[,rownames(three_four)]
dim(Rcounts_three_four)#52114 15
#subset clusters 1 and 2
one_two <- sev_meta[sev_meta$Group == "Cluster_1" | sev_meta$Group == "Cluster_2",]
one_two$Group <- as.factor(as.character(unlist(one_two$Group)))
Rcounts_one_two <- ribo_minus[,rownames(one_two)]
dim(Rcounts_one_two)#52114 20
#subset clusters 2 and 3
two_three <- sev_meta[sev_meta$Group == "Cluster_2" | sev_meta$Group == "Cluster_3",]
two_three$Group <- as.factor(as.character(unlist(two_three$Group)))
Rcounts_two_three <- ribo_minus[,rownames(two_three)]
dim(Rcounts_two_three)#52114 20
#subset clusters 2 and 4
two_four <- sev_meta[sev_meta$Group == "Cluster_2" | sev_meta$Group == "Cluster_4",]
two_four$Group <- as.factor(as.character(unlist(two_four$Group)))
Rcounts_two_four <- ribo_minus[,rownames(two_four)]
dim(Rcounts_two_four)#52114 15
#----------
#MAD filter test
one_four_mad <- apply(as.matrix(Rcounts_one_four), 1,mad) 
quantile(one_four_mad)
# 0%        25%        50%        75%       100% 
# 0.0000     0.0000     0.0000     2.9652 98228.1804
keep <- names(which(one_four_mad>quantile(one_four_mad)[4]))
one_four_F <- as.matrix(Rcounts_one_four)[keep,]
dim(one_four_F)#11134

#MAD filter test
one_three_mad <- apply(as.matrix(Rcounts_one_three), 1,mad) 
quantile(one_three_mad)
# 0%         25%         50%         75%        100% 
# 0.0000      0.0000      0.0000      2.9652 105151.9224 
keep <- names(which(one_three_mad>quantile(one_three_mad)[4]))
one_three_F <- as.matrix(Rcounts_one_three)[keep,]
dim(one_three_F)#11972
junk <- as.matrix(Rcounts_one_three)[-which(one_three_mad>quantile(one_three_mad)[4]),]
head(junk)
# #OR clusters 4 and 3
#MAD filter test
three_four_mad <- apply(as.matrix(Rcounts_three_four), 1,mad) 
quantile(three_four_mad)
# 0%        25%        50%        75%       100% 
# 0.0000     0.0000     0.0000     2.9652 95755.2036
keep <- names(which(three_four_mad>quantile(three_four_mad)[4]))
three_four_F <- as.matrix(Rcounts_three_four)[keep,]
dim(three_four_F)#10812
# 
#Clusters 1 and 2 filter
one_two_mad <- apply(as.matrix(Rcounts_one_two), 1,mad) 
quantile(one_two_mad)
# 0%         25%         50%         75%        100% 
# 0.0000      0.0000      0.0000      2.2239 128216.7306
keep <- names(which(one_two_mad>quantile(one_two_mad)[4]))
one_two_F <- as.matrix(Rcounts_one_two)[keep,]
dim(one_two_F)#12808
#
#Clusters 2 and 3 filter
two_three_mad <- apply(as.matrix(Rcounts_two_three), 1,mad) 
quantile(two_three_mad)
# 0%         25%         50%         75%        100% 
# 0.0000      0.0000      0.0000      2.2239 114352.9380 
keep <- names(which(two_three_mad>quantile(two_three_mad)[4]))
two_three_F <- as.matrix(Rcounts_two_three)[keep,]
dim(two_three_F)#12539 20
#
#Clusters 2 and 4 filter
two_four_mad <- apply(as.matrix(Rcounts_two_four), 1,mad) 
quantile(two_four_mad)
# 0%         25%         50%         75%        100% 
# 0.0000      0.0000      0.0000      1.4826 113455.9650  
keep <- names(which(two_four_mad>quantile(two_four_mad)[4]))
two_four_F <- as.matrix(Rcounts_two_four)[keep,]
dim(two_four_F)#12396 15
#-----
#MAD filter full dataset
all_mad <- apply(ribo_minus[,-1],1,mad) 
quantile(all_mad)
# 0%         25%         50%         75%        100% 
# 0.0000      0.0000      0.0000      2.9652 117340.3770 
keep <- names(which(all_mad>quantile(all_mad)[4]))
all_F <- ribo_minus[keep,-1]
dim(all_F)#10978
#---------------------------------------------
#Gene-level DGE analysis: The object Data should be a G − by − S matrix containing the expression values for each gene and
# each sample, where G is the number of genes and S is the number of samples. These values should exhibit
# raw counts, without normalization across samples. Counts of this nature may be obtained from RSEM [4],
# Cufflinks, or a similar approach.
#---------------------------------------------
#Calculate library size factors:
# As detailed in Section 3, EBSeq requires the library size factor ls for each sample s. Here, ls may be obtained
# via the function MedianNorm, which reproduces the median normalization approach in DESeq.
Sizes=MedianNorm(all_F)
Sizes

size_one_four <- MedianNorm(one_four_F)
# size_one_four <- MedianNorm(cnts)
# size_one_four <- MedianNorm(as.matrix(Rcounts_one_four))

size_one_three <- MedianNorm(one_three_F)
# size_one_three <- MedianNorm(cnts)
# size_one_three <- MedianNorm(as.matrix(Rcounts_one_three))
# JNK_10    JNK_11    JNK_12    JNK_13    JNK_14    JNK_15    JNK_16    JNK_17    JNK_18    JNK_19    JNK_30    JNK_31    JNK_32 
# 0.9800924 1.6002241 1.9754201 0.9896606 0.5460387 1.0462078 1.1166482 1.5761184 0.5638810 0.9677661 0.2642791 1.5586986 0.9442443 
# JNK_33    JNK_34    JNK_35    JNK_36    JNK_37    JNK_38    JNK_39 
# 0.6769953 1.0544489 0.9748088 1.0798720 2.1034768 1.4322659 0.8860855
size_three_four <- MedianNorm(three_four_F)
# size_three_four <- MedianNorm(cnts)
# size_three_four <- MedianNorm(as.matrix(Rcounts_three_four))
#
size_one_two <- MedianNorm(one_two_F)
#
size_two_three <- MedianNorm(two_three_F)
#
size_two_four <- MedianNorm(two_four_F)
#---------------------------------------------
# The function EBTest is used to detect DE genes. For gene-level data, we don’t need to specify the parameter
# NgVector since there are no differences in Ig structure among the different genes
table(one_four$Group)
# Cluster_1 Cluster_4 
# 10         5 
table(one_three$Group)
# Cluster_1 Cluster_3 
# 10        10 
#----
table(sev_meta$Condition)
# Fib No_Fib 
# 20     15 
#----
#Fibrosis vs. no fibrosis
EBOut=EBTest(Data=as.matrix(all_F),Conditions = sev_meta$Condition,sizeFactors=Sizes, maxround=20)
#note: The default value for maxround is 5. Users should always check the convergency by looking at the Alpha and Beta in output. 
# If the hyper-parameter estimations are not converged in 5 iterations, larger number is suggested.
EBOut$Alpha#
EBOut$Beta#
EBOut$P#
#Get results:
EBDERes=GetDEResults(EBOut, FDR=0.1, Threshold_FC = 0.8)
head(EBDERes$PPMat)
length(which(EBDERes$Status=="DE"))#0 fibrosis vs no fibrosis
#----
#----
#Sm infection vs. no infection
EBOut=EBTest(Data=as.matrix(all_F),Conditions = sev_meta$infection,sizeFactors=Sizes, maxround=20)
EBOut$Alpha#
EBOut$Beta#
EBOut$P#
#Get results:
EBDERes=GetDEResults(EBOut, FDR=0.1, Threshold_FC = 0.8)
head(EBDERes$PPMat)
length(which(EBDERes$Status=="DE"))#0 Sm infection vs no infection
#----
#Cluster 1 vs. 4
# EBOut=EBTest(Data=cnts,Conditions = one_four$Group,sizeFactors=size_one_four, maxround=10)
# EBOut=EBTest(Data=as.matrix(Rcounts_one_four),Conditions = one_four$Group,sizeFactors=size_one_four, maxround=10)
EBOut=EBTest(Data=as.matrix(one_four_F),Conditions = one_four$Group,sizeFactors=size_one_four, maxround=10)

EBOut$Alpha#
EBOut$Beta#
EBOut$P#
#Get results:
EBDERes=GetDEResults(EBOut, FDR=0.1, Threshold_FC = 0.8)
head(EBDERes$PPMat)
length(which(EBDERes$Status=="DE"))#24 differentially expressed genes between cluster 1 vs. cluster 4
sig <- which(EBDERes$Status=="DE")
sig_anno <- RM_anno[names(sig),]
#Calculate fold change values:
# The function PostFC may be used to calculate the Fold Change (FC) of the raw data as well as the posterior
# FC of the normalized data.  The posterior
# FC tends to shrink genes with low expressions (small rank);
GeneFC=PostFC(EBOut)
str(GeneFC)
sig_table <- data.frame(na.omit(EBDERes$PPMat[EBDERes$Status=="DE",]),sig_anno)
head(sig_table)
dim(sig_table)#24 cluster 1 vs. 4 
sig_table <- data.frame(sig_table,GeneFC$RealFC[rownames(sig_table)])
head(sig_table)
colnames(sig_table)[ncol(sig_table)] <- "realFC"
write.csv(sig_table,"cluster_1_vs_4_EBseq_sig_table_MAD_filtered.csv")
#----
table(three_four$Group)
#----
#Cluster 1 vs. 3
EBOut=EBTest(Data=one_three_F,Conditions = one_three$Group,sizeFactors=size_one_three, maxround=10)
EBOut$Alpha#
EBOut$Beta#
EBOut$P#
EBDERes=GetDEResults(EBOut, FDR=0.1, Threshold_FC = 0.8)
head(EBDERes$PPMat)
length(which(EBDERes$Status=="DE"))#4 differentially expressed genes between cluster 1 vs. cluster 3
sig <- which(EBDERes$Status=="DE")
sig_anno <- RM_anno[names(sig),]
#Calculate fold change values:
GeneFC=PostFC(EBOut)
str(GeneFC)
sig_table <- data.frame(na.omit(EBDERes$PPMat[EBDERes$Status=="DE",]),sig_anno)
head(sig_table)
dim(sig_table)#4 cluster 1 vs. 3
sig_table <- data.frame(sig_table,GeneFC$RealFC[rownames(sig_table)])
head(sig_table)
colnames(sig_table)[ncol(sig_table)] <- "realFC"
write.csv(sig_table,"cluster_1_vs_3_EBseq_sig_table_MAD_filtered.csv")
#----
#Cluster 1 vs. 2
EBOut=EBTest(Data=one_two_F,Conditions = one_two$Group,sizeFactors=size_one_two, maxround=10)

EBOut$Alpha#
EBOut$Beta#
EBOut$P#
EBDERes=GetDEResults(EBOut, FDR=0.1, Threshold_FC = 0.8)
head(EBDERes$PPMat)
length(which(EBDERes$Status=="DE"))# 8 diff. expressed between cluster 1 vs. 2
sig <- which(EBDERes$Status=="DE")
sig_anno <- RM_anno[names(sig),]
#Calculate fold change values:
GeneFC=PostFC(EBOut)
str(GeneFC)
sig_table <- data.frame(na.omit(EBDERes$PPMat[EBDERes$Status=="DE",]),sig_anno)
head(sig_table)
dim(sig_table)#8 cluster 1 vs. 2
sig_table <- data.frame(sig_table,GeneFC$RealFC[rownames(sig_table)])
head(sig_table)
colnames(sig_table)[ncol(sig_table)] <- "realFC"
write.csv(sig_table,"cluster_1_vs_2_EBseq_sig_table_MAD_filtered.csv")
#----
#Cluster 2 vs. 3
EBOut=EBTest(Data=two_three_F,Conditions = two_three$Group,sizeFactors=size_two_three, maxround=10)

EBOut$Alpha#
EBOut$Beta#
EBOut$P#
EBDERes=GetDEResults(EBOut, FDR=0.1, Threshold_FC = 0.8)
head(EBDERes$PPMat)
length(which(EBDERes$Status=="DE"))# 0 diff. expressed between cluster 2 vs. 3

#----
#Cluster 3 vs. 4
EBOut=EBTest(Data=three_four_F,Conditions = three_four$Group,sizeFactors=size_three_four, maxround=10)

EBOut$Alpha#
EBOut$Beta#
EBOut$P#
EBDERes=GetDEResults(EBOut, FDR=0.1, Threshold_FC = 0.8)
head(EBDERes$PPMat)
length(which(EBDERes$Status=="DE"))#1 differentially expressed genes between cluster 4 vs. cluster 3
sig <- which(EBDERes$Status=="DE")
sig_anno <- RM_anno[names(sig),]
#Calculate fold change values:
GeneFC=PostFC(EBOut)
str(GeneFC)
sig_table <- data.frame(t(na.omit(EBDERes$PPMat[EBDERes$Status=="DE",])),sig_anno)#where only 1 sig entry
head(sig_table)
dim(sig_table)#1 cluster 3 vs. 4
sig_table <- data.frame(sig_table,GeneFC$RealFC[rownames(sig_table)])
head(sig_table)
colnames(sig_table)[ncol(sig_table)] <- "realFC"
write.csv(sig_table,"cluster_3_vs_4_EBseq_sig_table_MAD_filtered.csv")
#---
#Cluster 2 vs. 4
EBOut=EBTest(Data=two_four_F,Conditions = two_four$Group,sizeFactors=size_two_four, maxround=10)

EBOut$Alpha#
EBOut$Beta#
EBOut$P#
EBDERes=GetDEResults(EBOut, FDR=0.1, Threshold_FC = 0.8)
head(EBDERes$PPMat)
length(which(EBDERes$Status=="DE"))# 2 diff. expressed between cluster 2 vs. 4
sig <- which(EBDERes$Status=="DE")
sig_anno <- RM_anno[names(sig),]
#Calculate fold change values:
GeneFC=PostFC(EBOut)
str(GeneFC)
sig_table <- data.frame(na.omit(EBDERes$PPMat[EBDERes$Status=="DE",]),sig_anno)
head(sig_table)
dim(sig_table)#2 cluster 2 vs. 4
sig_table <- data.frame(sig_table,GeneFC$RealFC[rownames(sig_table)])
head(sig_table)
colnames(sig_table)[ncol(sig_table)] <- "realFC"
write.csv(sig_table,"cluster_2_vs_4_EBseq_sig_table_MAD_filtered.csv")
#---------------------------------------------


#compare with genes found to be significant by edgeR
# edgeR_sig <- read.csv2("edgeR_Unfiltered_input_cluster1_vs_4_FDR_0_1.csv", sep = ",", row.names = 1)
# edgeR_sig <- read.csv2("edgeR_Unfiltered_input_cluster1_vs_4_FDR_0_1.csv", sep = ",", row.names = 1)

head(edgeR_sig)
dim(edgeR_sig)#59
length(intersect(rownames(edgeR_sig),rownames(sig_table)))#5 only
intersect(rownames(edgeR_sig),rownames(sig_table))
sig_table[intersect(rownames(edgeR_sig),rownames(sig_table)),"external_gene_name"]
# [1] "AMPD3"   "DUS2"    "INADL"   "SEMA7A"  "TCP11L1"
pdf("plotpostvsrawFC.pdf")
PlotPostVsRawFC(EBOut,GeneFC)
dev.off()
#cluster 1 vs. 3
pdf("plotpostvsrawFC_cluster1_3.pdf")
PlotPostVsRawFC(EBOut,GeneFC)
dev.off()
#cluster 1 vs. 4
pdf("plotpostvsrawFC_cluster1_4.pdf")
PlotPostVsRawFC(EBOut,GeneFC)
dev.off()
pdf("plotpostvsrawFC_cluster1_2.pdf")
PlotPostVsRawFC(EBOut,GeneFC)
dev.off()
#
pdf("plotpostvsrawFC_cluster2_4.pdf")
PlotPostVsRawFC(EBOut,GeneFC)
dev.off()

#Heatmap of EBseq sig genes: first need to normalize using CPM
logCPM <- cpm(as.matrix(Rcounts_one_four), prior.count=2, log=TRUE)#prior.count is to avoid undefined values and to reduce
#OR
logCPM <- cpm(as.matrix(Rcounts_one_three), prior.count=2, log=TRUE)#prior.count is to avoid undefined values and to reduce 
#OR
logCPM <- cpm(as.matrix(ribo_minus[,-1]), prior.count=2, log=TRUE)#prior.count is to avoid undefined values and to reduce 

logCPM <- cpm(as.matrix(Rcounts_one_two), prior.count=2, log=TRUE)#prior.count is to avoid undefined values and to reduce 

#--------------------------
#Boxplots of genes listed as differentially exprssed fib vs no-fib by the previous bioinformatician
glist <- c("BCL6","MME","SPATA13","CLEC7A","TLR1","IGSF6","YPEL5","CCR1","KCN12","MFSD14B","GK",
           "RRM2B","KLHL2","ZNF445","IL5RA","PATJ")
temp_anno <- ribo_minus
rownames(temp_anno) <- temp_anno[,1]
ids <- c()
for(i in 1:length(glist)){
  id <- rownames(ribo_minus)[which(glist[i] == ribo_minus[,1])]
  ids <- c(ids,id)
}

setdiff(glist,RM_anno[ids,"external_gene_name"])
# "KCN12"   "MFSD14B" "PATJ"

pdf("boxplots_fib_Vs_no_fib_identified_previous_bioinformatician_as_sig.pdf",10,10)
par(mfrow = c(4,5))
for(i in 1: length(ids)){
  boxplot(unlist(ribo_minus[ids[i],-1])~sev_meta$Condition, las = 2, 
          xlab = ribo_minus[ids[i],1], ylab = "counts")
}
dev.off()
#redo with CPM
identical(colnames(logCPM),rownames(sev_meta))#T
pdf("boxplots_CPM_fib_Vs_no_fib_identified_previous_bioinformatician_as_sig.pdf",10,10)
par(mfrow = c(4,5))
for(i in 1: length(ids)){
  boxplot(unlist(logCPM[ids[i],])~sev_meta$Condition, las = 2, 
          xlab = ribo_minus[ids[i],1], ylab = "counts")
}
dev.off()

#--------------------------
#Schistosomiasis test boxplots (genes reported as significant by previous bioinformatician)
schisto <- c("TLR1","CCR1", "IL5RA","CASP5", "LTA4H", 
"SNORA48","ARSB","SNORD89","CNR2", "TEC", "DACH1", "GPR82", "CACNA1D", "SNORA34","KIAA1024","ACOT11",
"UBE2QL1","STAC","CYP7B1","PCDH20","NBPF19","CLEC7A","MT-ATP8",'MIRPL44')

ids <- c()
for(i in 1:length(schisto)){
  id <- rownames(ribo_minus)[which(schisto[i] == ribo_minus[,1])]
  ids <- c(ids,id)
}

setdiff(schisto,RM_anno[ids,"external_gene_name"])
# [1] "NBPF19"  "MIRPL44"

pdf("boxplots_schisto_Vs_no_schisto_identified_previous_bioinformatician_as_sig.pdf",15,10)
par(mfrow = c(5,6))
for(i in 1: length(ids)){
  boxplot(unlist(ribo_minus[ids[i],-1])~sev_meta$Condition, las = 2, 
          xlab = ribo_minus[ids[i],1], ylab = "counts")
}
dev.off()
#redo with CPM
identical(colnames(logCPM),rownames(sev_meta))#T
pdf("boxplots_CPM_schisto_vs_no_schisto_identified_previous_bioinformatician_as_sig.pdf",15,10)
par(mfrow = c(5,6))
for(i in 1: length(ids)){
  boxplot(unlist(logCPM[ids[i],])~sev_meta$Condition, las = 2, 
          xlab = ribo_minus[ids[i],1], ylab = "counts")
}
dev.off()


counts_sig <- as.matrix(logCPM)[rownames(sig_table),]
identical(rownames(sig_table),rownames(counts_sig))#T
rownames(counts_sig) <- sig_table$external_gene_name
identical(rownames(one_four),colnames(counts_sig))#T
# identical(rownames(one_three),colnames(counts_sig))#T
# identical(rownames(one_two),colnames(counts_sig))#T

# t.track <- one_four$Group
t.track <- one_three$Group
# t.track <- one_two$Group
pdf("cluster_1_vs_4_heatmap_row_scaled.pdf")
aheatmap(counts_sig, annCol = t.track, scale = "row")
dev.off()
#
pdf("cluster_1_vs_4_heatmap_manual_sort.pdf")
aheatmap(counts_sig, annCol = t.track, Colv = NA)
dev.off()
#
pdf("cluster_1_vs_3_heatmap.pdf")
aheatmap(counts_sig, annCol = t.track, cexRow = 0.2)
dev.off()
#
pdf("cluster_1_vs_3_heatmap_manual_sort.pdf")
aheatmap(counts_sig, annCol = t.track, cexRow = 0.2, Colv = NA)
dev.off()
#
pdf("cluster_1_vs_3_heatmap_row_scaled.pdf")
aheatmap(counts_sig, annCol = t.track, scale = "row", cexRow = 0.2)
dev.off()
#
pdf("cluster_1_vs_2_heatmap_row_scaled.pdf")
aheatmap(counts_sig, annCol = t.track, scale = "row", cexRow = 0.3)
dev.off()
pdf("cluster_1_vs_2_heatmap.pdf")
aheatmap(counts_sig, annCol = t.track, cexRow = 0.3)
dev.off()
pdf("cluster_1_vs_2_heatmap_manual_sort.pdf")
aheatmap(counts_sig, annCol = t.track, cexRow = 0.3, Colv = NA)
dev.off()

#------------------------------
# Checking the model fit and other diagnostics
# EBSeq relies on parametric assumptions that should be checked following
# each analysis. The QQP function may be used to assess prior assumptions. In practice, QQP generates the
# Q-Q plot of the empirical q’s vs. the simulated q’s from the Beta prior distribution with estimated hyperparameters
# data points should lie on the y = x line for both conditions if the Beta prior is appropriate.
pdf("cluster_1_4_QQplot.pdf")
par(mfrow=c(1,2))
QQP(EBOut)
dev.off()
#
pdf("cluster_1_3_QQplot.pdf")
par(mfrow=c(1,2))
QQP(EBOut)
dev.off()
#
pdf("cluster_1_2_QQplot.pdf")
par(mfrow=c(1,2))
QQP(EBOut)
dev.off()
# the DenNHist function may be used to check the density plot of empirical q’s vs the simulated q’s
# from the fitted Beta prior distribution
pdf("cluster_1_4_DenNHist.pdf")
par(mfrow=c(1,2))
DenNHist(EBOut)
dev.off()
#
pdf("cluster_1_3_DenNHist.pdf")
par(mfrow=c(1,2))
DenNHist(EBOut)
dev.off()
#
pdf("cluster_1_2_DenNHist.pdf")
par(mfrow=c(1,2))
DenNHist(EBOut)
dev.off()
#------------------------------



#/////////////////////
data(GeneMat)
str(GeneMat)
GeneMat.small = GeneMat[c(1:10,511:550),]
Sizes = MedianNorm(GeneMat.small)
EBOut = EBTest(Data = GeneMat.small,
               Conditions = as.factor(rep(c("C1","C2"), each = 5)),
               sizeFactors = Sizes, maxround = 5)
Out = GetDEResults(EBOut)
head(Out$PPMat)
head(Out$Status)
