#V2: IN THIS VERSION SAMPLES AND COUNTS ARE LEFT UNFILTERED FOR DOWNSTREAM ANALYSES AS I SUSPECT BIOLOGICAL VARIATION WAS BEING LOST WITH DEFAULT FILTERING STRATEGY
#Differential expression testing of first round of RNAseq from Severin, using edgeR
#Set the working directory to where your input files are located:
# setwd("/Users/katielennard/Documents/Academic/IDM_projects/Nono/Severin/")
setwd("~/iCloud_IDM/Nono/")

#Load the relevant packages, install as necessary with install.packages() or Bioconductor 'BiocManager'
library(edgeR)
library(NMF)
library(biomaRt)#gene annotation
library(ggfortify)#PCA plot
library(magrittr)#%>%
library(dplyr)
library(tibble)  # for `rownames_to_column` and `column_to_rownames`
library(statmod)#for estimateDisp with robust=TRUE
library(GO.db)
library(org.Hs.eg.db)
library(gplots)
#import counts:
Rcounts <- read.csv("merged_gene_counts_2.txt", sep = "\t", row.names = 1)
dim(Rcounts)#63677 41
head(Rcounts)
#Clean sample names:
colnames(Rcounts)
colnames(Rcounts) <- sub(".fwAligned.sortedByCoord.out.bam","",colnames(Rcounts))
colnames(Rcounts)
colnames(Rcounts) <- sapply(strsplit(colnames(Rcounts), "_S"), `[`, 1)
colnames(Rcounts)#clean
#Find empty rows
RS <- sort(rowSums(Rcounts[,-1]))
head(RS)
length(which(RS==0))#remove 10136 transcripts with only zero values
#Remove empty rows
Rcounts <- Rcounts[-which(rowSums(Rcounts[,-1])==0),]
dim(Rcounts)#53541
#import sample metadata
sev_meta <- read.csv2("Severin_Metadata.csv", sep =  ",", row.names = 1)
#check that sampleIDs overlap between metadata and counts table
all(rownames(sev_meta) %in% colnames(Rcounts))#TRUE
#create factor for infection status:s
sev_meta$infection <- rep(NA,length(rownames(sev_meta)))
sev_meta$infection <- ifelse(sev_meta$Group=="Cluster_1" | sev_meta$Group =="Cluster_2", "yes", "no")
sev_meta$infection <- as.factor(sev_meta$infection)
head(sev_meta)
#Make sure sample order is same between sev_meta and counts
tmp <- Rcounts[,rownames(sev_meta)]
Rcounts2 <- data.frame(Rcounts[,1],tmp)
colnames(Rcounts2)[1] <- "gene"
identical(rownames(sev_meta),colnames(Rcounts2)[-1])#TRUE
#santity check
Rcounts[1:10,"JNK_10"]
Rcounts2[1:10,"JNK_10"]
#same
table(sev_meta$Group)
# Cluster_1 Cluster_2 Cluster_3 Cluster_4 
# 10        10        10        10 
table(sev_meta$Condition)
# Fib No_Fib 
# 20     20 
table(sev_meta$infection)
# no yes 
# 20  20 

#---------------------------------------------------------------------------------------
#check which genes have more than one EnsembleID entry (row)
#NB these are not transcript duplicates, there are in some cases multiple Ensemble records referring to the same gene
#In some cases it's when a gene maps to more than one chromosome
#See https://www.researchgate.net/post/How_to_deal_with_multiple_ensemble_IDs_mapping_to_one_gene_symbol_in_a_RNA-Seq_dataset for details
#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
#NB: in a future version of this script these can be filtered by only keeping the entry with the largerst number of counts/expression
#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
gene_dups <- Rcounts2[duplicated(Rcounts2$gene),]
dim(gene_dups)
gene_dups <- unique(gene_dups$gene)
gene_dups <- as.character(unlist(gene_dups))
length(gene_dups)#151
count_dups <- Rcounts2[Rcounts2$gene %in% gene_dups,]
dim(count_dups)
count_dups <- count_dups[order(count_dups$gene),]
head(count_dups)
#---------------------------------------------------------------------------------------
#Make DGElist object for edgeR use
d <- DGEList(counts=as.matrix(Rcounts2[,-1]),genes = Rcounts2[,1], group=factor(sev_meta$Group))
d
#-------------------EXPLORATORY QC----------------------------------------------------
pch <- c(0,1, 15, 23)#shapes for points on plot
colors <- c("blue","orange", "green", "red")
pdf("MDS_all_features_all_samples.pdf")
plotMDS(d, col=colors[sev_meta$Group], pch=pch[sev_meta$Group])
legend("topright", legend=levels(sev_meta$Group), pch=pch, col=colors, ncol=2)
dev.off()
#Four outliers in cluster 4  - is this library depth dependent?
#There are also two outliers from cluster 1 (JNK_16, JNK_18) and one from cluster 2 (JNK_24) that are outliers but not based on lib size (identities from multiQC report) 
#One thing that JNK16/18/24 have in common (together with JNK12) is a larger proportion of intronic reads (see multiQC report)
sampleQC <- data.frame(colSums(d$counts), sev_meta$Group) 
sampleQC %>%
  rownames_to_column('sample') %>%
  arrange(.,colSums.d.counts.) %>%
  column_to_rownames('sample')

#Looking at the first 16 entries sorted by lib size we do see 4 of cluster 1 samlpes have significantly smaller lib sizes than any of the other samples
# colSums.d.counts. sev_meta.Group
# JNK_42            104233      Cluster_4
# JNK_43            121535      Cluster_4
# JNK_44            124565      Cluster_4
# JNK_49            152779      Cluster_4
# JNK_47            234038      Cluster_4
# JNK_30            416488      Cluster_3
# JNK_20            911487      Cluster_2
# JNK_14            939440      Cluster_1
# JNK_18            956639      Cluster_1
# JNK_28           1117471      Cluster_2
# JNK_46           1132815      Cluster_4
# JNK_27           1191323      Cluster_2
# JNK_33           1210331      Cluster_3
# JNK_26           1254402      Cluster_2
# JNK_19           1287441      Cluster_1
# JNK_24           1317629      Cluster_2
boxplot(colSums(d$counts))
median(colSums(d$counts))#1558108
#-------------------EXPLORATORY QC----------------------------------------------------

#---------------------GENE ANNOTATION-----------------------------------------
#Lets start by filtering out any remaining rRNA in this dataset
# mart = useMart('ensembl')
# # list all the ensembl database of organisms
# listDatasets(mart)  
# #choose database of your interest ; in this case its "cfamiliaris_gene_ensembl" I guess
# ensembl = useMart( "ensembl", dataset = "hsapiens_gene_ensembl" , host = "grch37.ensembl.org")  
# # choose attributes of your interest
# listAttributes(ensembl)
# gene <- getBM( attributes = c("ensembl_gene_id","external_gene_name","description", "percentage_gene_gc_content"),values = rownames(Rcounts2),mart = ensembl)  
# head(gene)
# rownames(gene) <- gene$ensembl_gene_id
# dim(gene)#63677 for gchr37
# length(intersect(rownames(gene), rownames(Rcounts2)))#53541 for gchr37 (USED)
# saveRDS(gene,"severin_ensembl_gchr37_annotation.rds")
gene <- readRDS("severin_ensembl_gchr37_annotation.rds")#to reload
#---------------------GENE ANNOTATION------------------------------------------------

#---------------------DESIGN MATRIX--------------------------------------------------
design <- model.matrix(~0+Group, data=sev_meta)#force intercept through zero so as not to select any one group as 'reference'
design

#Calculate normalisation factors used as a scaling factor for the library sizes (they will be stored in y$samples$norm.factors)
y <- calcNormFactors(d,log=TRUE)
#
y <- estimateDisp(y, design, robust = TRUE)
#
levels(sev_meta$Group)
# "Cluster_1" "Cluster_2" "Cluster_3" "Cluster_4"
#----------------------------------
#For code below, see https://f1000research.com/articles/5-1438
#<<<<MD plots>>>>
# The expression profiles of individual samples can be explored more closely with mean-difference (MD) plots. 
# An MD plot visualizes the library size-adjusted log-fold change between two libraries (the difference) against 
# the average log-expression across those libraries (the mean). The following command produces an MD plot that 
# compares sample 1 to an artificial reference library constructed from the average of all the other samples:
pdf("MD_plots_raw_counts_unfiltered.pdf")
par(mfrow = c(4,4))
for(i in 1: length(colnames(y$counts))){
  plotMD(y, column=i)
  abline(h=0, col="red", lty=2, lwd=2)
}
dev.off()
#<<<<Biological coeff of variation>>>>>
#"..the asymptotic value for the BCV tends to be in range from 0.05 to 0.2 
#for genetically identical mice or cell lines, whereas somewhat larger values (> 0.3) are observed for human subjects.
plotBCV(y)
#<<<<<<<<<QL dispersion>>>>>>>>>>>>>>>>
#----------------------------------
#MODEL SELECTION
#There are several options in edgeR for differential experssion testing including glmFit, glmQLFit and exactTest  
#glmQLFit accounts for the uncertainty of the dispersion estimates 
#(which can be considerable when you have few replicates and/or the amount of shrinkage is low), whereas the other methods do not.
#glmQLFit uses the trended NB dispersion to fit a GLM, and then estimates the QL dispersion from the deviance. 
#It doesn't re-estimate the NB dispersion but instead estimates an entirely different QL dispersion for each gene. 
#In contrast, glmFit uses the tagwise NB dispersion to fit a GLM - and that's it.
#For glmQLFit any irregularity in the initial GLM fit will manifest as a change in the distribution of the deviances, 
#but such changes will end up being modelled by glmQLFit via estimation of f2$var.prior or f2$df.prior. 
#Any (deviance-based) goodness-of-fit testing that includes the QL dispersion would effectively cancel itself out, 
#because the purpose of the QL dispersion is to model any "non-goodness of fit", 
#WE will use glmQLFit which has less distributional assumptions 
fit <- glmQLFit(y, design, robust=TRUE)
#<<<<<<<<<<<<,Make contrasta>>>>>>>>>>>>>
#Severin-requested DGE comparisons:
# Group 1 Vs Group 2
# Group 1 Vs Group 3
# Group 1 Vs Group 4
# Group 2 Vs Group 3
# Group 2 Vs Group 4
# Group 3 Vs Group 4
# (Group 1 + Group 3) Vs (Group 2 + Group 4) 
sev_meta
design
colnames(design) <- sub("Group","",colnames(design))
#Make contrasts table group 1 vs 2.
contrast <- makeContrasts(Cluster_1-Cluster_2, levels=design)
contrast
# Contrasts
# Levels      Cluster_1 - Cluster_2
# Cluster_1                     1
# Cluster_2                    -1
# Cluster_3                     0
# Cluster_4                     0
res <- glmQLFTest(fit, contrast=contrast)
res
TT <- topTags(res, n = Inf)
summary(decideTestsDGE(res))#NS
write.csv(TT$table, paste0(getwd(),"/curated/edgeR_cluster_1_2_full_table.csv"))
#Make contrasts table group 1 vs 3.
contrast <- makeContrasts(Cluster_1-Cluster_3, levels=design)
res <- glmQLFTest(fit, contrast=contrast)
summary(decideTestsDGE(res))#
TT_cluster_1_3 <- topTags(res,n=Inf)
write.csv(TT_cluster_1_3$table, paste0(getwd(),"/curated/edgeR_cluster_1_3_full_table.csv"))
save <- TT_cluster_1_3$table[TT_cluster_1_3$table$FDR <= 0.1,]
save$annotation <- gene[rownames(save) ,"description"]
head(save)
write.csv(save, file = "edgeR_Unfiltered_input_cluster1_vs_3_FDR_0_1.csv")
#Make contrasts table group 1 vs 4.
contrast <- makeContrasts(Cluster_1-Cluster_4, levels=design)
res <- glmQLFTest(fit, contrast=contrast)
summary(decideTestsDGE(res))#
TT_cluster_1_4 <- topTags(res, n = Inf)
write.csv(TT_cluster_1_4$table, paste0(getwd(),"/curated/edgeR_cluster_1_4_full_table.csv"))

save <- TT_cluster_1_4$table[TT_cluster_1_4$table$FDR <= 0.1,]
save$annotation <- gene[rownames(save) ,"description"]
write.csv(save, file = "edgeR_Unfiltered_input_cluster1_vs_4_FDR_0_1.csv")
#Make contrasts table group 2 vs 3.
contrast <- makeContrasts(Cluster_2-Cluster_3, levels=design)
res <- glmQLFTest(fit, contrast=contrast)
summary(decideTestsDGE(res))#NS
TT_cluster_2_3 <- topTags(res, n = Inf)
write.csv(TT_cluster_2_3$table, paste0(getwd(),"/curated/edgeR_cluster_2_3_full_table.csv"))

#Make contrasts table group 2 vs 4.
contrast <- makeContrasts(Cluster_2-Cluster_4, levels=design)
res <- glmQLFTest(fit, contrast=contrast)
summary(decideTestsDGE(res))#NS
TT_cluster_2_4 <- topTags(res, n=Inf)
write.csv(TT_cluster_2_4$table, paste0(getwd(),"/curated/edgeR_cluster_2_4_full_table.csv"))

#Make contrasts table group 3 vs 4.
contrast <- makeContrasts(Cluster_3-Cluster_4, levels=design)
res <- glmQLFTest(fit, contrast=contrast)
summary(decideTestsDGE(res))#1 down
TT_cluster_3_4 <- topTags(res, n= Inf)
write.csv(TT_cluster_3_4$table, paste0(getwd(),"/curated/edgeR_cluster_3_4_full_table.csv"))

head(TT_cluster_3_4$table)
TT_cluster_3_4$table[TT_cluster_3_4$table$FDR <= 0.05,]
# genes      logFC   logCPM        F       PValue        FDR
# ENSG00000152778 IFIT5 -0.8254026 5.977888 25.92234 4.309322e-07 0.02307254
save <- TT_cluster_3_4$table[TT_cluster_3_4$table$FDR <= 0.1,]
save$annotation <- gene[rownames(save) ,"description"]
write.csv(save, file = "edgeR_Unfiltered_input_cluster3_vs_4_FDR_0_1.csv")

#Now for the fibrosis (cluster 1+3) vs no fibrosis (cluster2+4) comparison
design <- model.matrix(~0+Condition, data=sev_meta)#force intercept through zero so as not to select any one group as 'reference'
design
colnames(design)
#Calculate normalisation factors used as a scaling factor for the library sizes (they will be stored in y$samples$norm.factors)
y <- calcNormFactors(d,log=TRUE)
#
y <- estimateDisp(y, design, robust = TRUE)
fit <- glmQLFit(y, design, robust=TRUE)
contrast <- makeContrasts(ConditionFib-ConditionNo_Fib, levels = design)
# Contrasts
# Levels            ConditionFib - ConditionNo_Fib
# ConditionFib                                 1
# ConditionNo_Fib                             -1
contrast
res <- glmQLFTest(fit, contrast=contrast)
summary(decideTestsDGE(res))#NS
TT_cluster_fib_vs_no_fib <- topTags(res, n= Inf)
write.csv(TT_cluster_fib_vs_no_fib$table, paste0(getwd(),"/curated/edgeR_cluster_fibrosis_vs_no_fibrosis_full_table.csv"))
#-------------------------------------------------------
#11 Feb 2020 add-on request from Justin Nono: (C1+C2) vs C4 and C4 vs (C1+C2+C3)
sev_meta
# (C1+C2) vs C4: infection vs. no_infection_no_fibrosis
subA <- sev_meta[sev_meta$Group !="Cluster_3",]
subA$model <- ifelse(subA$Group=="Cluster_1" | subA$Group=="Cluster_2","infection","no_infection_no_fibrosis")
design <- model.matrix(~0+model, data=subA)#force intercept through zero so as not to select any one group as 'reference'
design
colnames(design)
#Calculate normalisation factors used as a scaling factor for the library sizes (they will be stored in y$samples$norm.factors)
d <- DGEList(counts=as.matrix(Rcounts2[,rownames(subA)]),genes = Rcounts2[,1], group=factor(subA$model))

y <- calcNormFactors(d,log=TRUE)
#
y <- estimateDisp(y, design, robust = TRUE)
fit <- glmQLFit(y, design, robust=TRUE)
contrast <- makeContrasts(modelinfection-modelno_infection_no_fibrosis, levels = design)
# Contrasts
# Levels                          modelinfection - modelno_infection_no_fibrosis
# modelinfection                                                             1
# modelno_infection_no_fibrosis                                             -1
contrast
res <- glmQLFTest(fit, contrast=contrast)
summary(decideTestsDGE(res))#NS
TT_cluster_A <- topTags(res, n= Inf)
head(TT_cluster_A$table)
write.csv(TT_cluster_A$table, paste0(getwd(),"/curated/edgeR_cluster_all_infection_vs_no_infection_no_fibrosis_full_table.csv"))
TT_cluster_A_sig <- TT_cluster_A$table[TT_cluster_A$table$FDR <= 0.1,]
dim(TT_cluster_A_sig)#104
write.csv(TT_cluster_A_sig$table, paste0(getwd(),"/curated/edgeR_cluster_all_infection_vs_no_infection_no_fibrosis_FDR_0_01.csv"))
#------------------------------------------------------------------------------------
# C4 vs (C1+C2+C3): no infection, no fibrosis vs. all other samples (infection and/or fibrosis)
subB <- sev_meta
subB$model <- ifelse(subB$Group=="Cluster_4","no_infection_no_fibrosis","other")
design <- model.matrix(~0+model, data=subB)#force intercept through zero so as not to select any one group as 'reference'
design
colnames(design) <-  c("no_infection_no_fibrosis","other")
#Calculate normalisation factors used as a scaling factor for the library sizes (they will be stored in y$samples$norm.factors)
d <- DGEList(counts=as.matrix(Rcounts2[,rownames(subB)]),genes = Rcounts2[,1], group=factor(subB$model))

y <- calcNormFactors(d,log=TRUE)
#
y <- estimateDisp(y, design, robust = TRUE)
fit <- glmQLFit(y, design, robust=TRUE)
contrast <- makeContrasts(other-no_infection_no_fibrosis, levels = design)
# Contrasts
# Levels                     other - no_infection_no_fibrosis
# no_infection_no_fibrosis                               -1
# other                                                   1                                  
contrast
res <- glmQLFTest(fit, contrast=contrast)
summary(decideTestsDGE(res))#NS
TT_cluster_B <- topTags(res, n= Inf)
head(TT_cluster_B$table)
write.csv(TT_cluster_B$table, paste0(getwd(),"/curated/edgeR_cluster_no_infection_no_fibrosis_vs_all_other_full_table.csv"))
TT_cluster_B_sig <- TT_cluster_B$table[TT_cluster_B$table$FDR <= 0.1,]
dim(TT_cluster_B_sig)#0
#---------------------DESIGN MATRIX--------------------------------------------------

#LEts do a heatmap for the comparison of cluster 1 vs. 4 which yielded the highest number of significant features to visually confirm DGE results
#Convert reads to counts per million (raw)
#On log2 transformation for cpm():https://support.bioconductor.org/p/77193/
# Depending on what clustering you're doing, you'll probably want to set log=TRUE as well. 
# This stabilizes the variance between genes of different abundance. Otherwise, high-abundance genes with correspondingly 
# large variances would dominate the calculations, e.g., for Euclidean distances. 
# This probably wouldn't be helpful, as you'd end up clustering on the measurement error/random variability of 
# constitutive housekeeping genes rather than on interesting biological differences in genes that are expressed at lower abundances.
#Let's see what MDS looks like: where a distance metric appropriate to microarray context is used
# The distance between each pair of samples (columns) is the root-mean-square deviation (Euclidean distance) 
# for the top top genes. Distances on the plot can be interpreted as leading log2-fold-change, 
# meaning the typical (root-mean-square) log2-fold-change between the samples for the genes that distinguish those samples.

logCPM <- cpm(y, prior.count=2, log=TRUE)#prior.count is to avoid undefined values and to reduce 
#the variability of the logCPM values for genes with low counts. 
#Larger values for prior.count shrink the logFCs for low count genes towards zero

#CPM will provide TMM-normalized counts, write to file (note that htis is with the first design model.matrix(~0+Group, data=sev_meta))
logCPM[1:10,1:10]
y$counts[1:10,1:10]
colSums(logCPM)
# JNK_10    JNK_11    JNK_12    JNK_13    JNK_14    JNK_15    JNK_16    JNK_17    JNK_18    JNK_19    JNK_20    JNK_21    JNK_22    JNK_23    JNK_24 
# 82386.64  84967.18  98804.12  78168.29  78946.91  82326.06 114914.65  86036.83 103175.77  83042.93  79369.65  79744.32  80542.55  82528.00 108108.36 
# JNK_25    JNK_26    JNK_27    JNK_28    JNK_29    JNK_30    JNK_31    JNK_32    JNK_33    JNK_34    JNK_35    JNK_36    JNK_37    JNK_38    JNK_39 
# 79587.55  75626.94  77207.29  77321.47  78057.48  75830.22  82098.22  78454.83  84680.37  82445.14  79034.31  79105.07  91579.46  85237.44  77795.37 
# JNK_40    JNK_41    JNK_42    JNK_43    JNK_44    JNK_45    JNK_46    JNK_47    JNK_48    JNK_49 
# 78060.98  92097.81  68382.74  69185.23  71238.75  77363.90  78753.93  81248.95  77423.47  72141.82 
#write normalised data to file:
head(y$counts)
head(d$counts)
#Add annotation data
head(gene)
norm_counts <- data.frame(logCPM)
norm_counts$annotation <- gene[rownames(logCPM),"external_gene_name"]
norm_counts$description <- gene[rownames(logCPM),"description"]
head(norm_counts)
#sanity check
gene["ENSG00000223972",]
gene["ENSG00000227232",]
write.csv(norm_counts, file = paste0(getwd(),"/log2_normalized_gene_counts.csv"), row.names = TRUE)

norm_counts[288,]
k <- grep("RP11-34P13",gene$external_gene_name)
gene[k,]
#extract significant features:
C1_C4samples <- sev_meta[sev_meta$Group=="Cluster_1" | sev_meta$Group =="Cluster_4",]
C1_C4 <- TT_cluster_1_4$table[TT_cluster_1_4$table$FDR <= 0.1,]
logCPM_C1_C4 <- logCPM[rownames(C1_C4),rownames(C1_C4samples)]
dim(logCPM_C1_C4)#59 20
rownames(logCPM_C1_C4) <- y$genes[rownames(logCPM_C1_C4),1]
head(logCPM_C1_C4)
#Set colour scale
col.pan <- colorpanel(100, "blue", "white", "red")
#Set sample annotation track
t.track = sev_meta[rownames(C1_C4samples),]
t.track$Group <- as.factor(as.character(unlist(t.track$Group)))
t.track$Condition <-as.factor(as.character(unlist(t.track$Condition)))  
t.track$infection <-as.factor(as.character(unlist(t.track$infection)))  
pdf("heatmap_filtered_log2_CPM_C1_C4_FDR_0_1.pdf")
aheatmap(logCPM_C1_C4, annCol = t.track)
dev.off()
#------------------------------------------------------------------------------------


